drop _all
log using uipdata, replace
*
* This STATA program stacks up the RS2 data and performs UIP tests
*
set more 1
set maxobs 4000
*
* First set up the new data (since 7/1/92)
*
infile using \res\uip\data\newd1
replace year=year+1900
sort year month day
save crap1,replace
drop _all
infile using \res\uip\data\newd2
replace year=year+1900
sort year month day
save crap2,replace
drop _all
infile using \res\uip\data\newd3
replace year=year+1900
sort year month day
save crap3,replace
drop _all
infile using \res\uip\data\newd4
replace year=year+1900
g respot=1./re
drop re
sort year month day
save crap4,replace
drop _all
*
* Merge it all together
*
use crap1
merge year month day using crap2
tab _merge
drop _merge
sort year month day
merge year month day using crap3
tab _merge
drop _merge
sort year month day
merge year month day using crap4
tab _merge
drop _merge
sort year month day
*
* Reshape interest rates
*
g dds=(1200.*log(1.+(di1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g eds=(1200.*log(1.+(ei1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g fds=(1200.*log(1.+(fi1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g hds=(1200.*log(1.+(hi1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g ids=(1200.*log(1.+(ii1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g rds=(1200.*log(1.+(ri1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g yds=(1200.*log(1.+(yi1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g pds=(1200.*log(1.+(pi1/1200.)))-(1200.*log(1.+(gi1/1200.)))
g bds=(1200.*log(1.+(bi1/1200.)))-(1200.*log(1.+(gi1/1200.)))

replace dds=-999999 if dds==.
replace eds=-999999 if eds==.
replace fds=-999999 if fds==.
replace hds=-999999 if hds==.
replace ids=-999999 if ids==.
replace rds=-999999 if rds==.
replace yds=-999999 if yds==.
replace pds=-999999 if pds==.
replace bds=-999999 if bds==.

g ddm=(400.*log(1.+(di3/400.)))-(400.*log(1.+(gi3/400.)))
g edm=(400.*log(1.+(ei3/400.)))-(400.*log(1.+(gi3/400.)))
g fdm=(400.*log(1.+(fi3/400.)))-(400.*log(1.+(gi3/400.)))
g hdm=(400.*log(1.+(hi3/400.)))-(400.*log(1.+(gi3/400.)))
g idm=(400.*log(1.+(ii3/400.)))-(400.*log(1.+(gi3/400.)))
g rdm=(400.*log(1.+(ri3/400.)))-(400.*log(1.+(gi3/400.)))
g ydm=(400.*log(1.+(yi3/400.)))-(400.*log(1.+(gi3/400.)))
g pdm=(400.*log(1.+(pi3/400.)))-(400.*log(1.+(gi3/400.)))
g bdm=(400.*log(1.+(bi3/400.)))-(400.*log(1.+(gi3/400.)))

replace ddm=-999999 if ddm==.
replace edm=-999999 if edm==.
replace fdm=-999999 if fdm==.
replace hdm=-999999 if hdm==.
replace idm=-999999 if idm==.
replace rdm=-999999 if rdm==.
replace ydm=-999999 if ydm==.
replace pdm=-999999 if pdm==.
replace bdm=-999999 if bdm==.

drop di1 ei1 fi1 gi1 hi1 ii1 ri1 yi1 pi1 bi1 di3 ei3 fi3 gi3 hi3 ii3 ri3 yi3 pi3 bi3
*
* Reshape exchange rates
*
g de=despot/gespot
g ee=eespot/gespot
g fe=fespot/gespot
g he=hespot/gespot
g ie=iespot/gespot
g re=respot/gespot
g ye=yespot/gespot
g pe=pespot/gespot
g be=bespot/gespot

replace de=-999999 if de==.
replace ee=-999999 if ee==.
replace fe=-999999 if fe==.
replace he=-999999 if he==.
replace ie=-999999 if ie==.
replace re=-999999 if re==.
replace ye=-999999 if ye==.
replace pe=-999999 if pe==.
replace be=-999999 if be==.

drop despot eespot fespot gespot hespot iespot respot yespot pespot bespot

save crap,replace
drop _all
*
* Incorporate the older data (data for Portugal,Spain and the UK pre 10/92)
*
use \res\uip\data\pre1092
sort year month day
merge year month day using crap
tab _merge
drop _merge
*
* Reshape rates
*
replace yds=-999999 if yds==.
replace pds=-999999 if pds==.
replace bds=-999999 if bds==.

replace ydm=-999999 if ydm==.
replace pdm=-999999 if pdm==.
replace bdm=-999999 if bdm==.

replace ye=-999999 if ye==.
replace pe=-999999 if pe==.
replace be=-999999 if be==.

sort year month day
save crap,replace
drop _all
*
* Read in the data and drop some junk
*
use \res\uip\data\data1
drop dil-ril dc-obs dmonth-rreg sc
*
* Prepare to stack up the data
*
* Reshape interest rates
*
g dds=dis-gis
g eds=eis-gis
g fds=fis-gis
g hds=his-gis
g ids=iis-gis
g rds=ris-gis
drop dis-ris

replace dds=-999999 if dds==.
replace eds=-999999 if eds==.
replace fds=-999999 if fds==.
replace hds=-999999 if hds==.
replace ids=-999999 if ids==.
replace rds=-999999 if rds==.

g ddm=dim-gim
g edm=eim-gim
g fdm=fim-gim
g hdm=him-gim
g idm=iim-gim
g rdm=rim-gim
drop dim-rim

replace ddm=-999999 if ddm==.
replace edm=-999999 if edm==.
replace fdm=-999999 if fdm==.
replace hdm=-999999 if hdm==.
replace idm=-999999 if idm==.
replace rdm=-999999 if rdm==.
*
* Reshape exchange rates
*
replace de=-999999 if de==.
replace ee=-999999 if ee==.
replace fe=-999999 if fe==.
replace he=-999999 if he==.
replace ie=-999999 if ie==.
replace re=-999999 if re==.

replace ddreg=-999999 if ddreg==.
replace dereg=-999999 if dereg==.
replace dfreg=-999999 if dfreg==.
replace dhreg=-999999 if dhreg==.
replace direg=-999999 if direg==.
replace drreg=-999999 if drreg==.
*
* Merge with the newer data
*
sort year month day
merge year month day using crap
tab _merge
drop _merge
*
* Create the realignment variables for the three late ERM entrants
*
g dyreg=0
g dpreg=0
g dbreg=0

replace dyreg=-999999 in 1/2679
replace dpreg=-999999 in 1/3409
replace dbreg=-999999 in 1/3019

replace dyreg=1 in 3527/3527
replace dyreg=1 in 3575/3575
replace dyreg=1 in 3700/3700
replace dyreg=1 in 3755/3755

replace dpreg=1 in 3575/3575
replace dpreg=1 in 3700/3700
replace dpreg=1 in 3755/3755

replace dbreg=2 in 3527/l
*
* Realignments for post 10/92 ERM
*
replace ddreg=0 in 3556/l
replace dereg=0 in 3556/l
replace dfreg=0 in 3556/l
replace dhreg=0 in 3556/l
replace drreg=0 in 3556/l

replace direg=1 in 3525/3525
replace direg=1 in 3527/3527
replace direg=2 in 3528/l

replace ddreg=1 in 3755/3755

replace dereg=1 in 3755/3755

replace dfreg=1 in 3755/3755

replace drreg=1 in 3625/3625
replace drreg=1 in 3755/3755

order de ee fe he ie re ye pe be dds eds fds hds ids rds yds pds bds ddm edm fdm hdm idm rdm ydm pdm bdm ddreg dereg dfreg dhreg direg drreg dyreg dpreg dbreg year month day

sort year month day
drop month day
compress
save crap,replace
drop _all
set maxobs 40000
*
* Write it out after stacking, variable by variable
*
use crap
stack dds-bds, into(int1) clear
g t=_n
replace int1=. if int1==-999999
sort t _stack
save crapi1,replace
drop _all

use crap
stack ddm-bdm, into(int3) clear
g t=_n
replace int3=. if int3==-999999
sort t _stack
save crapi3,replace
drop _all

use crap
stack de-be, into(erate) clear
g t=_n
replace erate=. if erate==-999999
sort t _stack
save crape,replace
drop _all

use crap
stack ddreg-dbreg, into(regime) clear
g t=_n
replace regime=. if regime==-999999
sort t _stack
save crapr,replace
drop _all

use crap
stack year year year year year year year year year, into(year) clear
g t=_n
replace year=. if year==-999999
sort t _stack
save crapy,replace
drop _all
*
* Merge it back in to create the pooled data
*
use crapi1
merge t _stack using crapi3
tab _merge
drop _merge
sort t _stack

merge t _stack using crape
tab _merge
drop _merge
sort t _stack

merge t _stack using crapr
tab _merge
drop _merge
sort t _stack

merge t _stack using crapy
tab _merge
drop _merge
sort t _stack

sum
*
* Now work on the pooled data.  First create the transformations
*
* Create variables for change in parity
*
g byte dc22=0
replace dc22=1 if regime[_n+1]==1 in 2/l
replace dc22=1 if regime[_n+2]==1 in 2/l
replace dc22=1 if regime[_n+3]==1 in 2/l
replace dc22=1 if regime[_n+4]==1 in 2/l
replace dc22=1 if regime[_n+5]==1 in 2/l
replace dc22=1 if regime[_n+6]==1 in 2/l
replace dc22=1 if regime[_n+7]==1 in 2/l
replace dc22=1 if regime[_n+8]==1 in 2/l
replace dc22=1 if regime[_n+9]==1 in 2/l
replace dc22=1 if regime[_n+10]==1 in 2/l
replace dc22=1 if regime[_n+11]==1 in 2/l
replace dc22=1 if regime[_n+12]==1 in 2/l
replace dc22=1 if regime[_n+13]==1 in 2/l
replace dc22=1 if regime[_n+14]==1 in 2/l
replace dc22=1 if regime[_n+15]==1 in 2/l
replace dc22=1 if regime[_n+16]==1 in 2/l
replace dc22=1 if regime[_n+17]==1 in 2/l
replace dc22=1 if regime[_n+18]==1 in 2/l
replace dc22=1 if regime[_n+19]==1 in 2/l
replace dc22=1 if regime[_n+20]==1 in 2/l
replace dc22=1 if regime[_n+21]==1 in 2/l
replace dc22=1 if regime[_n+22]==1 in 2/l
tab dc22

g byte dc65=0
replace dc65=1 if regime[_n+1]==1 in 2/l
replace dc65=1 if regime[_n+2]==1 in 2/l
replace dc65=1 if regime[_n+3]==1 in 2/l
replace dc65=1 if regime[_n+4]==1 in 2/l
replace dc65=1 if regime[_n+5]==1 in 2/l
replace dc65=1 if regime[_n+6]==1 in 2/l
replace dc65=1 if regime[_n+7]==1 in 2/l
replace dc65=1 if regime[_n+8]==1 in 2/l
replace dc65=1 if regime[_n+9]==1 in 2/l
replace dc65=1 if regime[_n+10]==1 in 2/l
replace dc65=1 if regime[_n+11]==1 in 2/l
replace dc65=1 if regime[_n+12]==1 in 2/l
replace dc65=1 if regime[_n+13]==1 in 2/l
replace dc65=1 if regime[_n+14]==1 in 2/l
replace dc65=1 if regime[_n+15]==1 in 2/l
replace dc65=1 if regime[_n+16]==1 in 2/l
replace dc65=1 if regime[_n+17]==1 in 2/l
replace dc65=1 if regime[_n+18]==1 in 2/l
replace dc65=1 if regime[_n+19]==1 in 2/l
replace dc65=1 if regime[_n+20]==1 in 2/l
replace dc65=1 if regime[_n+21]==1 in 2/l
replace dc65=1 if regime[_n+22]==1 in 2/l
replace dc65=1 if regime[_n+23]==1 in 2/l
replace dc65=1 if regime[_n+24]==1 in 2/l
replace dc65=1 if regime[_n+25]==1 in 2/l
replace dc65=1 if regime[_n+26]==1 in 2/l
replace dc65=1 if regime[_n+27]==1 in 2/l
replace dc65=1 if regime[_n+28]==1 in 2/l
replace dc65=1 if regime[_n+29]==1 in 2/l
replace dc65=1 if regime[_n+30]==1 in 2/l
replace dc65=1 if regime[_n+31]==1 in 2/l
replace dc65=1 if regime[_n+32]==1 in 2/l
replace dc65=1 if regime[_n+33]==1 in 2/l
replace dc65=1 if regime[_n+34]==1 in 2/l
replace dc65=1 if regime[_n+35]==1 in 2/l
replace dc65=1 if regime[_n+36]==1 in 2/l
replace dc65=1 if regime[_n+37]==1 in 2/l
replace dc65=1 if regime[_n+38]==1 in 2/l
replace dc65=1 if regime[_n+39]==1 in 2/l
replace dc65=1 if regime[_n+40]==1 in 2/l
replace dc65=1 if regime[_n+41]==1 in 2/l
replace dc65=1 if regime[_n+42]==1 in 2/l
replace dc65=1 if regime[_n+43]==1 in 2/l
replace dc65=1 if regime[_n+44]==1 in 2/l
replace dc65=1 if regime[_n+45]==1 in 2/l
replace dc65=1 if regime[_n+46]==1 in 2/l
replace dc65=1 if regime[_n+47]==1 in 2/l
replace dc65=1 if regime[_n+48]==1 in 2/l
replace dc65=1 if regime[_n+49]==1 in 2/l
replace dc65=1 if regime[_n+50]==1 in 2/l
replace dc65=1 if regime[_n+51]==1 in 2/l
replace dc65=1 if regime[_n+52]==1 in 2/l
replace dc65=1 if regime[_n+53]==1 in 2/l
replace dc65=1 if regime[_n+54]==1 in 2/l
replace dc65=1 if regime[_n+55]==1 in 2/l
replace dc65=1 if regime[_n+56]==1 in 2/l
replace dc65=1 if regime[_n+57]==1 in 2/l
replace dc65=1 if regime[_n+58]==1 in 2/l
replace dc65=1 if regime[_n+59]==1 in 2/l
replace dc65=1 if regime[_n+60]==1 in 2/l
replace dc65=1 if regime[_n+61]==1 in 2/l
replace dc65=1 if regime[_n+62]==1 in 2/l
replace dc65=1 if regime[_n+63]==1 in 2/l
replace dc65=1 if regime[_n+64]==1 in 2/l
replace dc65=1 if regime[_n+65]==1 in 2/l
tab dc65
*
* Create variables for change in country
*
g byte dco22=0
replace dco22=1 if _stack[_n+1]~=_stack in 2/l
replace dco22=1 if _stack[_n+2]~=_stack in 2/l
replace dco22=1 if _stack[_n+3]~=_stack in 2/l
replace dco22=1 if _stack[_n+4]~=_stack in 2/l
replace dco22=1 if _stack[_n+5]~=_stack in 2/l
replace dco22=1 if _stack[_n+6]~=_stack in 2/l
replace dco22=1 if _stack[_n+7]~=_stack in 2/l
replace dco22=1 if _stack[_n+8]~=_stack in 2/l
replace dco22=1 if _stack[_n+9]~=_stack in 2/l
replace dco22=1 if _stack[_n+10]~=_stack in 2/l
replace dco22=1 if _stack[_n+11]~=_stack in 2/l
replace dco22=1 if _stack[_n+12]~=_stack in 2/l
replace dco22=1 if _stack[_n+13]~=_stack in 2/l
replace dco22=1 if _stack[_n+14]~=_stack in 2/l
replace dco22=1 if _stack[_n+15]~=_stack in 2/l
replace dco22=1 if _stack[_n+16]~=_stack in 2/l
replace dco22=1 if _stack[_n+17]~=_stack in 2/l
replace dco22=1 if _stack[_n+18]~=_stack in 2/l
replace dco22=1 if _stack[_n+19]~=_stack in 2/l
replace dco22=1 if _stack[_n+20]~=_stack in 2/l
replace dco22=1 if _stack[_n+21]~=_stack in 2/l
replace dco22=1 if _stack[_n+22]~=_stack in 2/l
tab dco22

g byte dco65=0
replace dco65=1 if _stack[_n+1]~=_stack in 2/l
replace dco65=1 if _stack[_n+2]~=_stack in 2/l
replace dco65=1 if _stack[_n+3]~=_stack in 2/l
replace dco65=1 if _stack[_n+4]~=_stack in 2/l
replace dco65=1 if _stack[_n+5]~=_stack in 2/l
replace dco65=1 if _stack[_n+6]~=_stack in 2/l
replace dco65=1 if _stack[_n+7]~=_stack in 2/l
replace dco65=1 if _stack[_n+8]~=_stack in 2/l
replace dco65=1 if _stack[_n+9]~=_stack in 2/l
replace dco65=1 if _stack[_n+10]~=_stack in 2/l
replace dco65=1 if _stack[_n+11]~=_stack in 2/l
replace dco65=1 if _stack[_n+12]~=_stack in 2/l
replace dco65=1 if _stack[_n+13]~=_stack in 2/l
replace dco65=1 if _stack[_n+14]~=_stack in 2/l
replace dco65=1 if _stack[_n+15]~=_stack in 2/l
replace dco65=1 if _stack[_n+16]~=_stack in 2/l
replace dco65=1 if _stack[_n+17]~=_stack in 2/l
replace dco65=1 if _stack[_n+18]~=_stack in 2/l
replace dco65=1 if _stack[_n+19]~=_stack in 2/l
replace dco65=1 if _stack[_n+20]~=_stack in 2/l
replace dco65=1 if _stack[_n+21]~=_stack in 2/l
replace dco65=1 if _stack[_n+22]~=_stack in 2/l
replace dco65=1 if _stack[_n+23]~=_stack in 2/l
replace dco65=1 if _stack[_n+24]~=_stack in 2/l
replace dco65=1 if _stack[_n+25]~=_stack in 2/l
replace dco65=1 if _stack[_n+26]~=_stack in 2/l
replace dco65=1 if _stack[_n+27]~=_stack in 2/l
replace dco65=1 if _stack[_n+28]~=_stack in 2/l
replace dco65=1 if _stack[_n+29]~=_stack in 2/l
replace dco65=1 if _stack[_n+30]~=_stack in 2/l
replace dco65=1 if _stack[_n+31]~=_stack in 2/l
replace dco65=1 if _stack[_n+32]~=_stack in 2/l
replace dco65=1 if _stack[_n+33]~=_stack in 2/l
replace dco65=1 if _stack[_n+34]~=_stack in 2/l
replace dco65=1 if _stack[_n+35]~=_stack in 2/l
replace dco65=1 if _stack[_n+36]~=_stack in 2/l
replace dco65=1 if _stack[_n+37]~=_stack in 2/l
replace dco65=1 if _stack[_n+38]~=_stack in 2/l
replace dco65=1 if _stack[_n+39]~=_stack in 2/l
replace dco65=1 if _stack[_n+40]~=_stack in 2/l
replace dco65=1 if _stack[_n+41]~=_stack in 2/l
replace dco65=1 if _stack[_n+42]~=_stack in 2/l
replace dco65=1 if _stack[_n+43]~=_stack in 2/l
replace dco65=1 if _stack[_n+44]~=_stack in 2/l
replace dco65=1 if _stack[_n+45]~=_stack in 2/l
replace dco65=1 if _stack[_n+46]~=_stack in 2/l
replace dco65=1 if _stack[_n+47]~=_stack in 2/l
replace dco65=1 if _stack[_n+48]~=_stack in 2/l
replace dco65=1 if _stack[_n+49]~=_stack in 2/l
replace dco65=1 if _stack[_n+50]~=_stack in 2/l
replace dco65=1 if _stack[_n+51]~=_stack in 2/l
replace dco65=1 if _stack[_n+52]~=_stack in 2/l
replace dco65=1 if _stack[_n+53]~=_stack in 2/l
replace dco65=1 if _stack[_n+54]~=_stack in 2/l
replace dco65=1 if _stack[_n+55]~=_stack in 2/l
replace dco65=1 if _stack[_n+56]~=_stack in 2/l
replace dco65=1 if _stack[_n+57]~=_stack in 2/l
replace dco65=1 if _stack[_n+58]~=_stack in 2/l
replace dco65=1 if _stack[_n+59]~=_stack in 2/l
replace dco65=1 if _stack[_n+60]~=_stack in 2/l
replace dco65=1 if _stack[_n+61]~=_stack in 2/l
replace dco65=1 if _stack[_n+62]~=_stack in 2/l
replace dco65=1 if _stack[_n+63]~=_stack in 2/l
replace dco65=1 if _stack[_n+64]~=_stack in 2/l
replace dco65=1 if _stack[_n+65]~=_stack in 2/l
tab dco65
*
* Create 1-month change in e
*
g d1mde=(100.*12.)*(log(erate[_n+22])-log(erate))
replace d1mde=. if dco22==1
*
* Create 3-month analogue
*
g d3mde=(100.*4.)*(log(erate[_n+65])-log(erate))
replace d3mde=. if dco65==1
*
* Drop earlier periods for Spain, Portugal and UK
*
drop if regime==.
*
* Adjust for Italian and British Floats
*
replace d1mde=. if regime[_n+1]==2 in 2/l
replace d1mde=. if regime[_n+2]==2 in 2/l
replace d1mde=. if regime[_n+3]==2 in 2/l
replace d1mde=. if regime[_n+4]==2 in 2/l
replace d1mde=. if regime[_n+5]==2 in 2/l
replace d1mde=. if regime[_n+6]==2 in 2/l
replace d1mde=. if regime[_n+7]==2 in 2/l
replace d1mde=. if regime[_n+8]==2 in 2/l
replace d1mde=. if regime[_n+9]==2 in 2/l
replace d1mde=. if regime[_n+10]==2 in 2/l
replace d1mde=. if regime[_n+11]==2 in 2/l
replace d1mde=. if regime[_n+12]==2 in 2/l
replace d1mde=. if regime[_n+13]==2 in 2/l
replace d1mde=. if regime[_n+14]==2 in 2/l
replace d1mde=. if regime[_n+15]==2 in 2/l
replace d1mde=. if regime[_n+16]==2 in 2/l
replace d1mde=. if regime[_n+17]==2 in 2/l
replace d1mde=. if regime[_n+18]==2 in 2/l
replace d1mde=. if regime[_n+19]==2 in 2/l
replace d1mde=. if regime[_n+20]==2 in 2/l
replace d1mde=. if regime[_n+21]==2 in 2/l
replace d1mde=. if regime[_n+22]==2 in 2/l

replace d3mde=. if regime[_n+1]==2 in 2/l
replace d3mde=. if regime[_n+2]==2 in 2/l
replace d3mde=. if regime[_n+3]==2 in 2/l
replace d3mde=. if regime[_n+4]==2 in 2/l
replace d3mde=. if regime[_n+5]==2 in 2/l
replace d3mde=. if regime[_n+6]==2 in 2/l
replace d3mde=. if regime[_n+7]==2 in 2/l
replace d3mde=. if regime[_n+8]==2 in 2/l
replace d3mde=. if regime[_n+9]==2 in 2/l
replace d3mde=. if regime[_n+10]==2 in 2/l
replace d3mde=. if regime[_n+11]==2 in 2/l
replace d3mde=. if regime[_n+12]==2 in 2/l
replace d3mde=. if regime[_n+13]==2 in 2/l
replace d3mde=. if regime[_n+14]==2 in 2/l
replace d3mde=. if regime[_n+15]==2 in 2/l
replace d3mde=. if regime[_n+16]==2 in 2/l
replace d3mde=. if regime[_n+17]==2 in 2/l
replace d3mde=. if regime[_n+18]==2 in 2/l
replace d3mde=. if regime[_n+19]==2 in 2/l
replace d3mde=. if regime[_n+20]==2 in 2/l
replace d3mde=. if regime[_n+21]==2 in 2/l
replace d3mde=. if regime[_n+22]==2 in 2/l
replace d3mde=. if regime[_n+23]==2 in 2/l
replace d3mde=. if regime[_n+24]==2 in 2/l
replace d3mde=. if regime[_n+25]==2 in 2/l
replace d3mde=. if regime[_n+26]==2 in 2/l
replace d3mde=. if regime[_n+27]==2 in 2/l
replace d3mde=. if regime[_n+28]==2 in 2/l
replace d3mde=. if regime[_n+29]==2 in 2/l
replace d3mde=. if regime[_n+30]==2 in 2/l
replace d3mde=. if regime[_n+31]==2 in 2/l
replace d3mde=. if regime[_n+32]==2 in 2/l
replace d3mde=. if regime[_n+33]==2 in 2/l
replace d3mde=. if regime[_n+34]==2 in 2/l
replace d3mde=. if regime[_n+35]==2 in 2/l
replace d3mde=. if regime[_n+36]==2 in 2/l
replace d3mde=. if regime[_n+37]==2 in 2/l
replace d3mde=. if regime[_n+38]==2 in 2/l
replace d3mde=. if regime[_n+39]==2 in 2/l
replace d3mde=. if regime[_n+40]==2 in 2/l
replace d3mde=. if regime[_n+41]==2 in 2/l
replace d3mde=. if regime[_n+42]==2 in 2/l
replace d3mde=. if regime[_n+43]==2 in 2/l
replace d3mde=. if regime[_n+44]==2 in 2/l
replace d3mde=. if regime[_n+45]==2 in 2/l
replace d3mde=. if regime[_n+46]==2 in 2/l
replace d3mde=. if regime[_n+47]==2 in 2/l
replace d3mde=. if regime[_n+48]==2 in 2/l
replace d3mde=. if regime[_n+49]==2 in 2/l
replace d3mde=. if regime[_n+50]==2 in 2/l
replace d3mde=. if regime[_n+51]==2 in 2/l
replace d3mde=. if regime[_n+52]==2 in 2/l
replace d3mde=. if regime[_n+53]==2 in 2/l
replace d3mde=. if regime[_n+54]==2 in 2/l
replace d3mde=. if regime[_n+55]==2 in 2/l
replace d3mde=. if regime[_n+56]==2 in 2/l
replace d3mde=. if regime[_n+57]==2 in 2/l
replace d3mde=. if regime[_n+58]==2 in 2/l
replace d3mde=. if regime[_n+59]==2 in 2/l
replace d3mde=. if regime[_n+60]==2 in 2/l
replace d3mde=. if regime[_n+61]==2 in 2/l
replace d3mde=. if regime[_n+62]==2 in 2/l
replace d3mde=. if regime[_n+63]==2 in 2/l
replace d3mde=. if regime[_n+64]==2 in 2/l
replace d3mde=. if regime[_n+65]==2 in 2/l
*
* Save it all
*
compress
save \res\uip\data\uippool,replace
*
* Close down
*
!del crap*.*
drop _all
log close
exit,clear
